@@ -20,7 +20,7 @@ logger = logging.getLogger(__name__)
 class GSPML(DataSourceOutputML):
     """Model for output of GSP data"""
 
-    # Shape: [batch_size,] seq_length, width, height, channel
+    # Shape: [batch_size,] seq_length, n_pv_systems_per_example
     gsp_yield: Array = Field(
         ...,
         description=" GSP yield from all GSP in the region of interest (ROI). \
@@ -28,6 +28,14 @@ class GSPML(DataSourceOutputML):
     : shape = [batch_size, ] seq_length, n_gsp_per_example",
     )
 
+    # Shape: [batch_size,] seq_length, n_pv_systems_per_example
+    gsp_capacity: Array = Field(
+        ...,
+        description=" GSP capacity from all GSP in the region of interest (ROI). \
+        : Includes central GSP system, which will always be the first entry. \
+        : shape = [batch_size, ] seq_length, n_gsp_per_example",
+    )
+
     #: GSP identification.
     #: shape = [batch_size, ] n_pv_systems_per_example
     gsp_id: Array = Field(..., description="gsp id from NG")
@@ -95,6 +103,11 @@ class GSPML(DataSourceOutputML):
                 seq_length_30,
                 n_gsp_per_batch,
             ).astype(np.float32),
+            gsp_capacity=np.random.randn(
+                batch_size,
+                seq_length_30,
+                n_gsp_per_batch,
+            ).astype(np.float32),
             gsp_id=np.sort(np.random.randint(0, 340, (batch_size, n_gsp_per_batch))),
             gsp_datetime_index=time_30,
             gsp_x_coords=np.sort(np.random.randn(batch_size, n_gsp_per_batch).astype(np.float32)),
@@ -112,9 +125,12 @@ class GSPML(DataSourceOutputML):
     def from_xr_dataset(xr_dataset):
         """Change xr dataset to model. If data does not exist, then return None"""
 
-        gsp_batch_ml = xr_dataset.torch.to_tensor(["data", "time", "x_coords", "y_coords", "id"])
+        gsp_batch_ml = xr_dataset.torch.to_tensor(
+            ["power_mw", "capacity_mwp", "time", "x_coords", "y_coords", "id"]
+        )
 
-        gsp_batch_ml[GSP_YIELD] = gsp_batch_ml.pop("data")
+        gsp_batch_ml[GSP_YIELD] = gsp_batch_ml.pop("power_mw")
+        gsp_batch_ml["gsp_capacity"] = gsp_batch_ml.pop("capacity_mwp")
         gsp_batch_ml[GSP_ID] = gsp_batch_ml.pop("id")
         gsp_batch_ml[GSP_DATETIME_INDEX] = gsp_batch_ml.pop("time")
         gsp_batch_ml[GSP_X_COORDS] = gsp_batch_ml.pop("x_coords")
@@ -122,3 +138,9 @@ class GSPML(DataSourceOutputML):
         gsp_batch_ml["batch_size"] = gsp_batch_ml[GSP_YIELD].shape[0]
 
         return GSPML(**gsp_batch_ml)
+
+    def normalize(self):
+        """Normalize the gsp data"""
+        if not self.normalized:
+            self.gsp_yield = self.gsp_yield - self.gsp_capacity
+            self.normalized = True
