@@ -19,31 +19,12 @@ logger = logging.getLogger(__name__)
 # nwp_ds.open()
 # mean = nwp_ds.data.isel(init_time=slice(0, 10)).mean(
 #     dim=['step', 'x', 'init_time', 'y']).compute()
-NWP_MEAN = [
-    2.8041010e02,
-    1.6854691e01,
-    6.7529683e-05,
-    8.1832832e01,
-    7.1233767e-03,
-    8.8566933e00,
-    4.3474598e04,
-    4.9820110e01,
-    4.8095409e01,
-    4.2833260e01,
-]
+NWP_MEAN = {'cdcb': 742.401, 'lcc': 66.756538, 'mcc': 157.74133, 'hcc': 15542.797, 'sde': 3.2133293, 'hcct': -5909.7021, 'dswrf': 49265.621, 'dlwrf': 167.16484, 'h': 1707.0344, 't': 171.22368, 'r': 63.139393, 'dpt': 158.05571, 'vis': 16480.631, 'si10': -5607.0537, 'wdir10': 151.85562, 'prmsl': 52296.281, 'prate': 975.62311}
+
+
+
+NWP_STD = {'cdcb': 1437.9733, 'lcc': 32.845642, 'mcc': 122.90843, 'hcc': 22072.18, 'sde': 4.2809649, 'hcct': 13865.189, 'dswrf': 50599.918, 'dlwrf': 165.04289, 'h': 1566.2006, 't': 118.57211, 'r': 35.996311, 'dpt': 128.49652, 'vis': 22340.301, 'si10': 13388.914, 'wdir10': 153.62816, 'prmsl': 50509.055, 'prate': 1263.6071}
 
-NWP_STD = [
-    2.5812180e00,
-    4.1278820e01,
-    2.7507244e-04,
-    9.0967312e00,
-    1.4110464e-01,
-    4.3616886e00,
-    2.3853148e04,
-    3.8900299e01,
-    4.2830105e01,
-    4.2778091e01,
-]
 
 
 class NWPML(DataSourceOutputML):
@@ -134,6 +115,12 @@ class NWPML(DataSourceOutputML):
     def normalize(self):
         """Normalize the nwp data"""
         if not self.normalized:
-            self.data = self.data - NWP_MEAN
-            self.data = self.data / NWP_STD
+            # Only take the channels that are used
+            mean = np.array([NWP_MEAN[b] for b in self.channels])
+            std = np.array([NWP_STD[b] for b in self.channels])
+            # Expand for normaliation
+            mean = np.expand_dims(mean, axis=[1, 2, 3])
+            std = np.expand_dims(std, axis=[1, 2, 3])
+            self.data = self.data - mean
+            self.data = self.data / std
             self.normalized = True
